@@ -136,8 +136,8 @@ def main():
     parser.add_argument(
         "-p", "--path_format",
         help=(
-            "Structure of output path/naming."
-            "Supported terms: author, narrator, "
+            "Structure of output path/naming. "
+            "Supported terms: asin, author, narrator, "
             "series_name, series_position, "
             "subtitle, title, year"
         ),
